I messed up the test case id to turn logging on and then off.  It is "test_long_type_with_dsym",
not "test_long_long_type_with_dsym".


git-svn-id: https://llvm.org/svn/llvm-project/llvdb/trunk@133562 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/test/types/TestFailures.py b/test/types/TestFailures.py
index 2cdfe17..ef1e257 100644
--- a/test/types/TestFailures.py
+++ b/test/types/TestFailures.py
@@ -17,9 +17,9 @@
     def setUp(self):
         # Call super's setUp().
         TestBase.setUp(self)
         # If we're lucky, test_long_long_type_with_dsym fails.
         # Let's turn on logging just for that.
-        if "test_long_long_type_with_dsym" in self.id():
+        if "test_long_type_with_dsym" in self.id():
             self.runCmd(
                 "log enable -n -f %s lldb commands event process state" % os.environ["DEBUG_LLDB_LOG"])
             self.runCmd(
@@ -28,9 +28,9 @@
     def tearDown(self):
         # Call super's tearDown().
         TestBase.tearDown(self)
         # If we're lucky, test_long_long_type_with_dsym fails.
         # Let's turn off logging just for that.
-        if "test_long_long_type_with_dsym" in self.id():
+        if "test_long_type_with_dsym" in self.id():
             self.runCmd("log disable lldb")
             self.runCmd("log disable gdb-remote")
@@ -17,9 +17,9 @@
         # Call super's setUp().
         TestBase.setUp(self)
-        # If we're lucky, test_long_long_type_with_dsym fails.
+        # If we're lucky, test_long_type_with_dsym fails.
         # Let's turn on logging just for that.
@@ -28,9 +28,9 @@
         # Call super's tearDown().
         TestBase.tearDown(self)
-        # If we're lucky, test_long_long_type_with_dsym fails.
+        # If we're lucky, test_long_type_with_dsym fails.
         # Let's turn off logging just for that.